# Modules

Modules implemented in slp. This list will get extended with modules geared towards multimodal processing soon.

::: slp.modules.attention
::: slp.modules.classifier
::: slp.modules.embed
::: slp.modules.feedforward
::: slp.modules.norm
::: slp.modules.regularization
::: slp.modules.rnn
::: slp.modules.transformer
